@@ -1,12 +1,11 @@
 # coding=utf-8
-import copy
-
-from pprint import PrettyPrinter
 
 from ..rest_client import AtlassianRestAPI
 
 
 class BitbucketBase(AtlassianRestAPI):
+    bulk_headers = {"Content-Type": "application/vnd.atl.bitbucket.bulk+json"}
+
     def __init__(self, url, *args, **kwargs):
         """
         Init the rest api wrapper
@@ -16,36 +15,38 @@ class BitbucketBase(AtlassianRestAPI):
 
         :return: nothing
         """
-        if "data" in kwargs:
-            self.__data = kwargs.pop("data")
-            expected_type = kwargs.pop("expected_type")
-            if not self.get_data("type") == expected_type:
-                raise ValueError(
-                    "Expected type of data is [{}], got [{}].".format(expected_type, self.get_data("type"))
-                )
-        if url is None:
-            url = self.get_link("self")
         super(BitbucketBase, self).__init__(url, *args, **kwargs)
 
-    def __str__(self):
-        return PrettyPrinter(indent=4).pformat(self.__data)
-
-    def _get_paged(self, url, params={}, data=None, flags=None, trailing=None, absolute=False):
+    def _get_paged(self, url, params=None, data=None, flags=None, trailing=None, absolute=False):
         """
         Used to get the paged data
         :param url:       The url to retrieve.
         :param params:    The parameters (optional).
         :param data:      The data (optional).
+        :param flags:     The flags (optional).
+        :param trailing:  If True, a trailing slash is added to the url (optional).
+        :param absolute:  If True, the url is used absolute and not relative to the root (optional).
 
-        :return: nothing
+        :return: A generator for the project objects
         """
 
+        if params is None:
+            params = {}
+
         while True:
             response = self.get(url, trailing=trailing, params=params, data=data, flags=flags, absolute=absolute)
             if "values" not in response:
                 return
 
-            for value in response.get("values", []):
+            values = response.get("values", [])
+            if not response.get("size", -1) == len(values):
+                raise AssertionError(
+                    "Wrong response for url [{}], the size attribute doesn't match the number of recieved values:\n{}".format(
+                        self.url, response
+                    )
+                )
+
+            for value in values:
                 yield value
 
             if self.cloud:
@@ -69,13 +70,3 @@ class BitbucketBase(AtlassianRestAPI):
             api_root=self.api_root,
             api_version=self.api_version,
         )
-
-    @property
-    def data(self):
-        return copy.copy(self.__data)
-
-    def get_data(self, id):
-        return copy.copy(self.__data[id])
-
-    def get_link(self, link):
-        return self.__data["links"][link]["href"]
